@@ -1600,24 +1600,24 @@ Sim::OPT::Interlinear
 
 
 Interlinear is a program for computing the missing values in multivariate datasieries pre-prepared in csv format.
-The program can adopt the following algorithmic strategies and intermix their result:
+The program can adopt the following algorithmic strategies and intermix their results:
 
-a) a propagating distance-weighted gradient-based strategy (by far the best one so far, keeping into account that the behaviour of factors is often not linear and there are curvatures all aroung the design space);
+a) a propagating distance-weighted gradient-based strategy (by far the best one so far, keeping into account that the behaviour of factors is often not linear and there are curvatures all around the design space);
 
-b) pure linear interpolation (one may want to use this in some occasions: for example, on factorials);
+b) pure linear interpolation (one may want to use this in some occasions: for example, with factorials);
 
 c) nearest neighbour (a strategy of last resort. One may want to use it to unlock a computation which is based on data which are too sparse to proceed, or when nothing else works).
 
 A configuration file should be prepared following the example in the "examples" folder in this distribution.
-If the configuration file is incomplete or missing, the program adopts its own defaults, exploiting the distance-weighted gradient-based strategy.
+If the configuration file is incomplete or missing, the will program adopt its own defaults, sticking to the distance-weighted gradient-based strategy.
 
 The only variable that must mandatorily be specified in a configuration file is $sourcefile : the Unix path to the source file containining the dataseries.
 
-The source file has to be prepared by listing in each column the values (levels) of the parameters (factors, variables), putting in the last column the objective function value, when present.
+The source file has to be prepared by listing in each column the values (levels) of the parameters (factors, variables), and putting in the last column the values of the objective function, when present.
 
 The parameter number is given by the position of the column (i.e. column 4 host parameter 4).
 
-Here below is shown an example of multivatiate dataseries of 3 parameters assuming 3 levels each. having with missing objecive function entries.
+Here below is shown an example of dataseries of 3 parameters assuming 3 levels each. having missing objecive function entries.
 
 
 1,1,1,1.234
